<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\BrandHome;
use Illuminate\Http\Request;

class BrandHomeController extends Controller
{
    public $resource = 'homeBrand';
    public $route = 'homeBrands';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function index()
    {
        $homeBrands = BrandHome::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.brand-home._table',compact('homeBrands'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.brand-home._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $homeBrandPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $homeBrandPhoto;
            BrandHome::query()->create($input);
        }
        return redirect()->route('dashboard.homeBrands.index')->with('success', 'Slider added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $homeBrand = BrandHome::query()->find($id);
        return view('admin.crud.brand-home._edit',compact('homeBrand'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $homeBrand = BrandHome::query()->find($id);
        $input = $request->all();
        if($request->hasFile('photo')  ) {
            $homeBrandPhoto = ImageHelper::add($request->photo, null, 'photo');
            $input['photo'] = $homeBrandPhoto;
        }
        $homeBrand->update($input);
        return redirect()->route('dashboard.homeBrands.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function destroy($id)
    {
        BrandHome::query()->where('id',$id)->first()->delete();
        return redirect()->route('dashboard.homeBrands.index')->with('Slider deleted successfully');
    }

    public function deleteImage(Request $request)
    {
        $homeBrand = BrandHome::query()->findOrFail($request->homeBrand_id);

        // Delete the existing identity photo
        if ($homeBrand->photo) {
            ImageHelper::delete($homeBrand->photo);
            $homeBrand->photo = 0;
            $homeBrand->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
