<?php

namespace App\Http\Controllers\Admin;

use App\Helper\ImageHelper;
use App\Http\Controllers\Controller;
use App\Models\Counter;
use Illuminate\Http\Request;

class CounterController extends Controller
{
    public $resource = 'counter';
    public $route = 'counters';

    public function __construct()
    {
        view()->share('item', $this->resource);
        view()->share('route', $this->route);
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $dataCounters = Counter::query()->orderBy('created_at', 'desc')->paginate(10);
        return view('admin.crud.counter._table',compact('dataCounters'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function create()
    {
        return view('admin.crud.counter._create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $input = $request->all();
        if($request->hasFile('counter_photo')  ) {
            $counterPhoto = ImageHelper::add($request->counter_photo, null, 'counter_photo');
            $input['counter_photo'] = $counterPhoto;
        }
        Counter::query()->create($input);
        return redirect()->route('dashboard.counters.index')->with('success', 'Product added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $counter = Counter::query()->find($id);
        return view('admin.crud.counter._show',compact('counter'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Contracts\Foundation\Application|\Illuminate\Contracts\View\Factory|\Illuminate\Contracts\View\View
     */
    public function edit($id)
    {
        $counter = Counter::query()->find($id);
        return view('admin.crud.counter._edit',compact('counter'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $counter = Counter::query()->find($id);
        $input = $request->all();

        if($request->hasFile('counter_photo')  ) {
            $counterPhoto = ImageHelper::add($request->counter_photo, null, 'counter_photo');
            $input['counter_photo'] = $counterPhoto;
        }
        $counter->update($input);
        return redirect()->route('dashboard.counters.index')->with('Slider updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Counter::query()->find($id)->delete();
        return redirect()->route('dashboard.counters.index')->with('success', 'Product added successfully');
    }

    public function deleteImage(Request $request)
    {
        $counter = Counter::query()->findOrFail($request->counter_id);

        // Delete the existing identity photo
        if ($counter->counter_photo) {
            ImageHelper::delete($counter->counter_photo);
            $counter->counter_photo = 0;
            $counter->save();

            return response()->json(['success' => true]);
        }

        return response()->json(['success' => false], 400);
    }
}
